"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.RadioButtonGroup = exports.RadioButton = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/extends"));
var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/objectWithoutPropertiesLoose"));
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _classnames = _interopRequireDefault(require("classnames"));
var _Radio = require("./Radio");
var _Button = require("../Button/Button");
require("./Radio.scss");
var _useControlledState2 = _interopRequireDefault(require("../../hooks/useControlledState/useControlledState"));
var _jsxRuntime = require("react/jsx-runtime");
var _excluded = ["label", "value", "className", "onClick", "onChange", "defaultChecked", "checked"],
  _excluded2 = ["className", "children", "elementType", "onChange", "name", "defaultValue", "value", "fullWidth"];
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
/**
 * The `<input type="radio">` defines a radio button styled like a button.
 * RadioButton buttons are normally presented in radio groups (a collection of radio buttons describing a set of related options). Only one radio button in a group can be selected at the same time.
 */
var RadioButton = /*#__PURE__*/(0, _react.forwardRef)(function (_ref, forwardedRef) {
  var label = _ref.label,
    value = _ref.value,
    className = _ref.className,
    onClick = _ref.onClick,
    onChange = _ref.onChange,
    _ref$defaultChecked = _ref.defaultChecked,
    defaultChecked = _ref$defaultChecked === void 0 ? false : _ref$defaultChecked,
    checked = _ref.checked,
    props = (0, _objectWithoutPropertiesLoose2.default)(_ref, _excluded);
  var radioGroupContext = (0, _react.useContext)(_Radio.RadioGroupContext) || {};
  var contextValue = radioGroupContext.value;
  var setContextState = radioGroupContext.setContextState;
  var _useControlledState = (0, _useControlledState2.default)(checked, defaultChecked),
    checkedState = _useControlledState[0],
    setCheckedState = _useControlledState[1];
  (0, _react.useEffect)(function () {
    if (contextValue === undefined) {
      return;
    }
    if (value !== undefined) {
      setCheckedState(contextValue === value);
    }
  }, [contextValue, setCheckedState, value]);
  var onClickHandler = function onClickHandler(event) {
    setCheckedState(!checkedState);
    if (setContextState) {
      setContextState(event, {
        value: checkedState ? undefined : value
      });
    }
    if (onClick) {
      onClick(event, checkedState ? undefined : value);
    }
  };
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Button.Button, (0, _extends2.default)({}, props, {
    onClick: onClickHandler,
    className: (0, _classnames.default)('sui-studio-doc-radio-button', {
      'sui-studio-doc-radio-button--checked': checkedState
    }, className),
    ref: forwardedRef,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Radio.Radio, {
      className: "sui-studio-doc-radio-button__radio",
      onChange: onChange,
      checked: checkedState,
      label: label,
      value: value
    })
  }));
});
exports.RadioButton = RadioButton;
RadioButton.displayName = 'RadioButton';
RadioButton.defaultProps = {};

/**
 * Radio button options element wrapper
 */
var RadioButtonGroup = /*#__PURE__*/(0, _react.forwardRef)(function (_ref2, forwardedRef) {
  var className = _ref2.className,
    children = _ref2.children,
    _ref2$elementType = _ref2.elementType,
    elementType = _ref2$elementType === void 0 ? 'div' : _ref2$elementType,
    onChange = _ref2.onChange,
    name = _ref2.name,
    defaultValue = _ref2.defaultValue,
    value = _ref2.value,
    fullWidth = _ref2.fullWidth,
    props = (0, _objectWithoutPropertiesLoose2.default)(_ref2, _excluded2);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Radio.RadioGroup, {
    onChange: onChange,
    name: name,
    defaultValue: defaultValue,
    value: value,
    fullWidth: fullWidth,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Button.ButtonGroup, (0, _extends2.default)({}, props, {
      className: (0, _classnames.default)('sui-studio-doc-radio-button', className),
      elementType: elementType,
      fullWidth: fullWidth,
      ref: forwardedRef,
      children: children
    }))
  });
});
exports.RadioButtonGroup = RadioButtonGroup;
RadioButtonGroup.displayName = 'RadioButtonGroup';
RadioButtonGroup.defaultProps = {};
var _default = RadioButton;
exports.default = _default;